@@ -89,14 +89,24 @@
 #' mean_colm = c("kurt", "sp.ent"), parallel = 1, pb = FALSE)
 #' }
 #'
-#' @references {
+#' @references 
 #' Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.
-#' }
+#' 
 #' @author Marcelo Araya-Salas (\email{marcelo.araya@@ucr.ac.cr})
-# last modification on may-8-2018 (MAS)
 
-song_analysis <- function(X = NULL, song_colm = "song", mean_colm = NULL, min_colm = NULL, max_colm = NULL, elm_colm = NULL, elm_fun = NULL,
-                          sd = FALSE, parallel = 1, pb = TRUE, na.rm = FALSE, weight = NULL) {
+song_analysis <- function(X = NULL,
+                          song_colm = "song",
+                          mean_colm = NULL,
+                          min_colm = NULL,
+                          max_colm = NULL,
+                          elm_colm = NULL,
+                          elm_fun = NULL,
+                          sd = FALSE,
+                          parallel = 1,
+                          pb = TRUE,
+                          na.rm = FALSE,
+                          weight = NULL
+) {
   #### set arguments from options
   # get function arguments
   argms <- methods::formalArgs(song_analysis)
